# Computed Field Plugin

This module provides a plugin to allow developers to create computed field via the Drupal Plugin API, and a field type 'computed_render_array'. 

Computed fields work a bit like extra fields but they are more flexible because you can still use the native field settings (including formatters).

You can use it to merge several fields as one in the display, or simply render a block, an entity...

For example, you have two link fields that you want to display in the same HTML block. You can create a computed field for that. You can still use your normal fields display if you want, it does not affect the original fields.

Another use case could be to render a block between your content fields. You could also decide to display the block according to another field value.

## How to use

```php
<?php

namespace Drupal\my_module\Plugin\ComputedField;

use Drupal\computed_field_plugin\Traits\ComputedSingleItemTrait;
use Drupal\Core\Field\FieldItemList;

/**
 * Class TestComputedField.
 *
 * @ComputedField(
 *   id = "test_computed_field",
 *   label = @Translation("Test computed field"),
 *   type = "computed_render_array",
*    entity_types = {"node"},
*    bundles = {"page"}
 * )
 */
class TestComputedField extends FieldItemList {

  use ComputedSingleItemTrait;

  /**
   * Handle single value.
   *
   * @return mixed
   *   Returns the computed value.
   */
  protected function singleComputeValue() {
    return [
      '#markup' => '<p>Lorem ipsum dolor sit amet, consectetur adipisicing elit. Asperiores, autem, delectus deleniti dolorum eligendi ipsa laborum mollitia numquam odit, placeat sed veniam voluptates. Expedita, nulla quam quo reprehenderit tenetur voluptatibus!</p>',
    ];
  }

}
```

The entity_types and bundles annotation properties expect an array, leave empty to allow all.
The label annotation property defines the field label as for any normal field.

## Twig

Example in node.html.twig:

```twig
{{ content.test_computed_field }}
```
Simply use the plugin id like a field machine name.
